# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Python3 introduced in Fedora 13
%global with_python3 %([ "(" "%{__distinit}" == "fc" -a %{__distvers} -gt 12 ")" ] && echo 1 || echo 0)

# __python2 macro defined from Fedora 16 onwards
%{!?__python2: %global __python2 python2}

%{!?python2_sitelib: %global python2_sitelib %(python2 -c "from distutils.sysconfig import get_python_lib; print get_python_lib()" 2>/dev/null)}
%{!?python3_sitelib: %global python3_sitelib %(python3 -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())" 2>/dev/null)}
%global python2ver %(python2 -c "import sys; print sys.version[:3]" 2>/dev/null || echo 0.0)
%global python3ver %(python3 -c "import sys; print(sys.version[:3])" 2>/dev/null || echo 0.0)

Name:		python-pyasn1
Version:	0.1.9
Release:	2.%{__distinit}%{__distvers}
Summary:	ASN.1 tools for Python
License:	BSD
Group:		System Environment/Libraries
Source0:	http://downloads.sf.net/pyasn1/pyasn1-%{version}.tar.gz
URL:		http://pyasn1.sourceforge.net/
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
BuildRequires:	coreutils
BuildRequires:	python-devel >= 2.4
BuildRequires:	python-setuptools
Provides:	python2-pyasn1 = %{version}-%{release}

%description
This project is dedicated to implementation of ASN.1 types (concrete syntax)
and codecs (transfer syntaxes) for the Python programming environment. ASN.1
compiler is planned for implementation in the future.

%if %{with_python3}
%package -n python3-pyasn1
Summary:	ASN.1 tools for Python 3
Group:		Development/Libraries
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools

%description -n python3-pyasn1
This project is dedicated to implementation of ASN.1 types (concrete syntax)
and codecs (transfer syntaxes) for the Python 3 programming environment. ASN.1
compiler is planned for implementation in the future.
%endif

%prep
%setup -n pyasn1-%{version} -q

# Remove upstream's egg-info
rm -rf pyasn1.egg-info

# Prepare python3 build
%if %{with_python3}
cp -a . %{py3dir}
%endif

%build
%{__python2} setup.py build

# Build for python3 too
%if %{with_python3}
cd %{py3dir}
%{__python3} setup.py build
cd -
%endif

%install
rm -rf %{buildroot}
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}

# Install for python3 too
%if %{with_python3}
cd %{py3dir}
%{__python3} setup.py install -O1 --skip-build --root %{buildroot}
cd -
%endif

# See if there's any Python 2 egg-info
if [ -d %{buildroot}%{python2_sitelib}/pyasn1-%{version}-py%{python2ver}.egg-info ]; then
	echo %{python2_sitelib}/pyasn1-%{version}-py%{python2ver}.egg-info/
fi > egg-info

%check
%{__python2} setup.py test

# Test for python3 too
%if %{with_python3}
cd %{py3dir}
%{__python3} setup.py test
cd -
%endif

%clean
rm -rf %{buildroot}

%files -f egg-info
%if 0%{?_licensedir:1}
%license LICENSE.txt
%else
%doc LICENSE.txt
%endif
%doc CHANGES.txt README.txt THANKS.txt TODO.txt doc/pyasn1-tutorial.html
%{python2_sitelib}/pyasn1/

%if %{with_python3}
%files -n python3-pyasn1
%if 0%{?_licensedir:1}
%license LICENSE.txt
%else
%doc LICENSE.txt
%endif
%doc CHANGES.txt README.txt THANKS.txt TODO.txt doc/pyasn1-tutorial.html
%{python3_sitelib}/pyasn1/
%{python3_sitelib}/pyasn1-%{version}-py%{python3ver}.egg-info/
%endif

%changelog
* Sat Feb 13 2016 Paul Howarth <paul@city-fan.org> - 0.1.9-2
- Add provide for python2-pyasn1

* Mon Oct 19 2015 Paul Howarth <paul@city-fan.org> - 0.1.9-1
- Update to 0.1.9
  - Wheel distribution format now supported
  - Extensions added to text files, CVS attic flushed
  - Fix to make uninitialized pyasn1 objects fail properly on hash()
  - Fix to ObjectIdentifier initialization from unicode string
  - Fix to CER/DER Boolean decoder - fail on non single-octet payload
- Add python3 package

* Thu Jul  2 2015 Paul Howarth <paul@city-fan.org> - 0.1.8-1
- Update to 0.1.8 (see CHANGES for details)
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Sun May  5 2013 Paul Howarth <paul@city-fan.org> - 0.1.7-1
- Update to 0.1.7
  - License updated to vanilla BSD 2-Clause to ease package use
    (http://opensource.org/licenses/BSD-2-Clause)
  - Test suite made discoverable by unittest/unittest2 discovery feature
  - Fix to decoder working on indefinite length substrate - end-of-octets
    marker is now detected by both tag and value. Otherwise zero values may
    interfere with end-of-octets marker
  - Fix to decoder to fail in cases where tagFormat indicates inappropriate
    format for the type (e.g. BOOLEAN is always PRIMITIVE, SET is always
    CONSTRUCTED and OCTET STRING is either of the two)
  - Fix to REAL type encoder to force primitive encoding form encoding
  - Fix to CHOICE decoder to handle explicitly tagged, indefinite length
    mode encoding
  - Fix to REAL type decoder to handle negative REAL values correctly

* Mon Jan  7 2013 Paul Howarth <paul@city-fan.org> - 0.1.6-1
- Update to 0.1.6
  - The compact (valueless) way of encoding zero INTEGERs introduced in 0.1.5
    seems to fail miserably as the world is filled with broken BER decoders,
    so we had to back off the *encoder* for a while (there's still the
    IntegerEncoder.supportCompactZero flag, which enables compact encoding form
    whenever it evaluates to True)
  - Report package version on debugging code initialization

* Thu Dec 20 2012 Paul Howarth <paul@city-fan.org> - 0.1.5-1
- Update to 0.1.5
  - Documentation updated and split into chapters to better match web-site
    contents
  - Make prettyPrint() working for non-initialized pyasn1 data objects (it used
    to throw an exception)
  - Fix to encoder to produce empty-payload INTEGER values for zeros
  - Fix to decoder to support empty-payload INTEGER and REAL values
  - Fix to unit test suite's imports to be able to run each from their current
    directory

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 0.1.4-1
- Update to 0.1.4
  - Built-in codec debugging facility added
  - Added some more checks to ObjectIdentifier BER encoder, catching possible
    2^8 overflow condition by two leading sub-OIDs
  - Implementations overriding the AbstractDecoder.valueDecoder method changed
    to return the rest of substrate behind the item being processed rather than
    the unprocessed substrate within the item (which is usually empty)
  - Decoder's recursiveFlag feature generalized as a user callback function,
    which is passed an uninitialized object recovered from substrate and its
    uninterpreted payload
  - Catch inappropriate substrate type passed to decoder
  - Expose tagMap/typeMap/Decoder objects at DER decoder to uniform API
  - Obsolete __init__.MajorVersionId replaced with __init__.__version__, which
    is now in sync with distutils
  - Package classifiers updated
  - The __init__.py's made non-empty (rumors are that they may be optimized out
    by package managers)
  - Bail out gracefully whenever Python version is older than 2.4
  - Fix to Real codec exponent encoding (should be in 2's complement form), and
    some more test cases added
  - Fix in Boolean truth testing built-in methods
  - Fix to substrate underrun error handling at ObjectIdentifier BER decoder
  - Fix to BER Boolean decoder that allows other pre-computed values besides
    0 and 1
  - Fix to leading 0x80 octet handling in DER/CER/DER ObjectIdentifier decoder
    (see http://www.cosic.esat.kuleuven.be/publications/article-1432.pdf)

* Mon Apr 23 2012 Paul Howarth <paul@city-fan.org> - 0.1.3-1
- Update to 0.1.3
  - Include class name into asn1 value constraint violation exception
  - Fix to OctetString.prettyOut() method that loses leading zero when
    building hex string

* Thu Dec  8 2011 Paul Howarth <paul@city-fan.org> - 0.1.2-1
- Update to 0.1.2
  - Fix to __long__() to actually return longs on py2k
  - Fix to OctetString.__str__() workings of a non-initialized object
  - Fix to quote initializer of OctetString.__repr__()
  - Minor fix towards ObjectIdentifier.prettyIn() reliability
  - ObjectIdentifier.__str__() is aliased to prettyPrint()
  - Explicit repr() calls replaced with '%%r'

* Mon Nov  7 2011 Paul Howarth <paul@city-fan.org> - 0.1.1-1
- Update to 0.1.1
  - Fix to base10 normalization function that loops on univ.Real(0)
  - Hex/bin string initializer to OctetString object reworked (in a
    backward-incompatible manner)
  - Fixed float() infinity compatibility issue (affects 2.5 and earlier)
  - Fixed a bug/typo at Boolean CER encoder
  - Major overhaul for Python 2.4-3.2 compatibility:
    - Get rid of old-style types
    - Drop string module usage
    - Switch to rich comparisons
    - Drop explicit long integer type use
    - map()/filter() replaced with list comprehension
    - apply() replaced with */**args
    - Switched to use 'key' sort() callback function
    - Support both __nonzero__() and __bool__() methods
    - Modified not to use py3k-incompatible exception syntax
    - getslice() operator fully replaced with getitem()
    - Dictionary operations made 2K/3K compatible
    - Base type for encoding substrate and OctetString-based types is now
      'bytes' when running py3k and 'str' otherwise
    - OctetString and derivatives now unicode-compliant
    - OctetString now supports two python-neutral getters: asOcts() and asInts()
    - Print OctetString content in hex whenever it is not printable otherwise
    - In test suite, implicit relative import replaced with the absolute one
    - In test suite, string constants replaced with numerics
- Package upstream CHANGES file
- Tweak test suite invocation to pick up test modules
- BR: python-devel ≥ 2.4; test suite fails with older pythons

* Thu Aug  4 2011 Paul Howarth <paul@city-fan.org> - 0.0.13b-2
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Apr 21 2011 Paul Howarth <paul@city-fan.org> - 0.0.13b-1
- Update to 0.0.13b
  - Major codec re-design
  - Documentation significantly improved
  - ASN.1 Any type is now supported
  - ASN.1 Real type is now supported properly
  - All example ASN.1 modules moved to separate pyasn1-modules package
  - Fix to initial sub-OID overflow condition detection an encoder
  - BitString initialization value verification improved
  - The Set/Sequence.getNameByPosition() method implemented
  - Fix to proper behaviour of PermittedAlphabetConstraint object
  - Fix to improper Boolean substrate handling at CER/DER decoders
  - Objects of Constructed types now support __setitem__()
  - Set/Sequence objects can now be addressed by their field names (string index)
    and position (integer index)
  - Typo fix to ber.SetDecoder code that prevented guided decoding operation
  - Fix to explicitly tagged items decoding support
  - Fix to OctetString.prettyPrint() to better handle non-printable content
  - Fix to repr() workings of Choice objects
  - Changes towards performance improvement:
    - All dict.has_key() & dict.get() invocations replaced with modern syntax
      (this breaks compatibility with Python 2.1 and older)
    - Tag and tagset caches introduced to decoder
    - decoder code improved to prevent unnecessary pyasn1 objects creation
    - Allow disabling components verification when setting components to
      structured types; this is used by decoder whilst running in guided mode
    - BER decoder for integer values now looks up a small set of pre-computed
      substrate values to save on decoding
    - A few pre-computed values configured to ObjectIdentifier BER encoder
    - ChoiceDecoder split-off SequenceOf one to save on unnecessary checks
    - Replace slow hasattr()/getattr() calls with isinstance() introspection
    - Track the number of initialized components of Constructed types to save
      on default/optional components initialization
    - Added a shortcut ObjectIdentifier.asTuple() to be used instead of
      __getitem__() in hotspots
    - Use Tag.asTuple() and pure integers at tag encoder
    - Introduce and use in decoder the baseTagSet attribute of the built-in
      ASN.1 types
- Drop patch for Any type, now supported upstream
- Package THANKS, TODO and pyasn1-tutorial.html
- Drop examples and notes.html documentation no longer provided by upstream

* Wed Apr 20 2011 Paul Howarth <paul@city-fan.org> - 0.0.12a-3
- Import from Fedora

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.12a-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 22 2010 Rob Crittenden <rcritten@redhat.com> - 0.0.12a-1
- Update to upstream version 0.0.12a

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 0.0.9a-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Mon Nov 16 2009 Rob Crittenden <rcritten@redhat.com> - 0.0.9a-1
- Update to upstream version 0.0.9a
- Include patch that adds parsing for the Any type

* Wed Sep  2 2009 Rob Crittenden <rcritten@redhat.com> - 0.0.8a-5
- Include doc/notes.html in the package

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.8a-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.8a-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 0.0.8a-2
- Rebuild for Python 2.6

* Tue Sep  9 2008 Paul P. Komkoff Jr <i@stingr.net> - 0.0.8a-1
- Update to upstream version 0.0.8a

* Wed Jan 16 2008 Rob Crittenden <rcritten@redhat.com> - 0.0.7a-4
- Use setuptools to install the package
- Simplify the files included in the rpm so it includes the .egg-info

* Mon Jan 14 2008 Rob Crittenden <rcritten@redhat.com> - 0.0.7a-3
- Rename to python-pyasn1
- Spec file cleanups

* Mon Nov 19 2007 Karl MacMillan <kmacmill@redhat.com> - 0.0.7a-2
- Update rpm to be more fedora friendly

* Thu Nov 8 2007 Simo Sorce <ssorce@redhat.com> 0.0.7a-1
- New release

* Mon May 28 2007 Andreas Hasenack <andreas@mandriva.com> 0.0.6a-1mdv2008.0
- Revision: 31989
- Fixed (build)requires
- Import pyasn1
